<?php

namespace Drupal\share_everywhere;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines a ShareEverywhereService service.
 */
class ShareEverywhereService implements ShareEverywhereServiceInterface {

  /**
   * The config object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs an ShareEverywhereService object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The Configuration Factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public function build($url, $id) {
    global $base_url;
    $config = $this->configFactory->get('share_everywhere.settings');
    $module_path = drupal_get_path('module', 'share_everywhere');
    $build = array('#theme' => 'share_everywhere');
    $buttons = array();
    $library = array();

    switch ($config->get('alignment')) {
      case 'left':
        $build['#attributes']['class'] = array(
          'se-align-left',
        );
        break;

      case 'right':
        $build['#attributes']['class'] = array(
          'se-align-right',
        );
        break;
    }

    foreach ($config->get('buttons') as $key => $button) {
      if ($key == 'facebook_like' && $button['enabled']) {
        $build['#facebook_like'] = array(
          '#theme' => 'se_facebook_like',
          '#url' => $url,
        );
        array_push($build['#attributes']['class'], 'se-has-like');
      }
      elseif ($button['enabled']) {
        $buttons[$key] = array(
          '#theme' => 'se_' . $key,
          '#url' => $url,
        );

        if ($key != 'facebook_like' && $config->get('style') == 'share_everywhere') {
          $buttons[$key]['#content'] = array(
            '#type' => 'html_tag',
            '#tag' => 'img',
            '#attributes' => array(
              'src' => $base_url . '/' . $module_path . '/img/' . $button['image'],
              'title' => t($button['title']),
              'alt' => t($button['title']),
            ),
          );
        }
        elseif ($config->get('style') == 'custom') {
          $buttons[$key]['#content'] = t($button['name']);
        }
      }
    }
    $build['#buttons'] = $buttons;
    $build['#se_links_id'] = 'se-links-' . $id;

    if ($config->get('display_title')) {
      $build['#title'] = t($config->get('title'));
    }

    $build['#share_icon'] = array(
      'id' => 'se-trigger-' . $id,
      'src' => $base_url . '/' . $module_path . '/img/' . $config->get('share_icon.image'),
      'alt' => t($config->get('share_icon.alt')),
    );

    if (!$config->get('collapsible')) {
      $build['#share_icon']['class'] = 'se-disabled';
    }

    if ($config->get('style') == 'share_everywhere') {
      if ($config->get('collapsible')) {
        $library = array(
          'share_everywhere/share_everywhere.css',
          'share_everywhere/share_everywhere.js',
        );
      }
      else {
        $library = array(
          'share_everywhere/share_everywhere.css',
        );
      }
    }
    elseif ($config->get('style') == 'custom') {
      if ($config->get('include_css')) {
        $library = array(
          'share_everywhere/share_everywhere.css',
        );
      }
      if ($config->get('include_js') && $config->get('collapsible')) {
        array_push($library, 'share_everywhere/share_everywhere.js');
      }
    }

    if (!$config->get('collapsible') || ($config->get('style') == 'custom' && !$config->get('include_js'))) {
      $build['#is_active'] = 'se-active';
    }
    elseif ($config->get('collapsible')) {
      $build['#is_active'] = 'se-inactive';
    }

    if (!empty($library)) {
      $build['#attached'] = array(
        'library' => $library,
      );
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function isRestricted($view_mode, $node_path) {
    $config = $this->configFactory->get('share_everywhere.settings');
    switch ($view_mode) {
      case 'search_result':
      case 'search_index':
      case 'rss':
        return TRUE;
    }
    $restricted_pages = $config->get('restricted_pages.pages');
    if (is_array($restricted_pages) && !empty($restricted_pages)) {
      $restriction_type = $config->get('restricted_pages.type');
      switch ($restriction_type) {
        case 'show':
          if ($restricted_pages[0] == '*' && !isset($restricted_pages[1])) {
            break;
          }
          else {
            foreach ($restricted_pages as $page) {
              $node_path = preg_split('/\//', $node_path, NULL, PREG_SPLIT_NO_EMPTY);
              $page = preg_split('/\//', $page, NULL, PREG_SPLIT_NO_EMPTY);
              if ($page[0] == '<front>') {
                $front_path = $this->configFactory->get('system.site')->get('page.front');
                $front_page = \Drupal::service('path.alias_manager')->getAliasByPath($front_path);
                $page = preg_split('/\//', $front_page, NULL, PREG_SPLIT_NO_EMPTY);
              }
              elseif (($wildcard = array_search('*', $page)) !== FALSE) {
                unset($node_path[$wildcard]);
                unset($page[$wildcard]);
              }
              if (empty(array_diff($node_path, $page))) {
                break 2;
              }
            }
          }
          return TRUE;

        case 'hide':
          if ($restricted_pages[0] == '*' && !isset($restricted_pages[1])) {
            return TRUE;
          }
          else {
            foreach ($restricted_pages as $page) {
              $node_path = preg_split('/\//', $node_path, NULL, PREG_SPLIT_NO_EMPTY);
              $page = preg_split('/\//', $page, NULL, PREG_SPLIT_NO_EMPTY);
              if ($page[0] == '<front>') {
                $front_path = $this->configFactory->get('system.site')->get('page.front');
                $front_page = \Drupal::service('path.alias_manager')->getAliasByPath($front_path);
                $page = preg_split('/\//', $front_page, NULL, PREG_SPLIT_NO_EMPTY);
              }
              elseif (($wildcard = array_search('*', $page)) !== FALSE) {
                unset($node_path[$wildcard]);
                unset($page[$wildcard]);
              }
              if (empty(array_diff($node_path, $page))) {
                return TRUE;
              }
            }
          }
          break;
      }
    }
    return FALSE;
  }

}
